==> manaplus_1.5.2.28.orig.tar.xz: manaplus-1.5.2.28/src/listeners/inputactionreplaylistener.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2015  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LISTENERS_INPUTACTIONREPLAYLISTENER_H
#define LISTENERS_INPUTACTIONREPLAYLISTENER_H

#include "listeners/actionlistener.h"

#include "input/inputaction.h"

#include "localconsts.h"

class EditDialog;

class InputActionReplayListener final : public ActionListener
{
    public:
        InputActionReplayListener();

        A_DELETE_COPY(InputActionReplayListener)

        void action(const ActionEvent &event) override final;

        void setDialog(EditDialog *const dialog)
        { mDialog = dialog; }

        void openDialog(const std::string &caption,
                        const std::string &text,
                        const InputAction::Type action0);

    protected:
        EditDialog *mDialog;
        InputAction::Type mAction;
};

extern InputActionReplayListener inputActionReplayListener;

#endif  // LISTENERS_INPUTACTIONREPLAYLISTENER_H

==> manaplus_1.5.8.15.orig.tar.xz: manaplus-1.5.8.15/src/listeners/inputactionreplaylistener.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2011-2015  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LISTENERS_INPUTACTIONREPLAYLISTENER_H
#define LISTENERS_INPUTACTIONREPLAYLISTENER_H

#include "enums/input/inputaction.h"

#include "listeners/actionlistener.h"

#include "localconsts.h"

class EditDialog;

class InputActionReplayListener final : public ActionListener
{
    public:
        InputActionReplayListener();

        A_DELETE_COPY(InputActionReplayListener)

        void action(const ActionEvent &event) override final;

        void setDialog(EditDialog *const dialog)
        { mDialog = dialog; }

        void openDialog(const std::string &caption,
                        const std::string &text,
                        const InputActionT action0);

    protected:
        EditDialog *mDialog;
        InputActionT mAction;
};

extern InputActionReplayListener inputActionReplayListener;

#endif  // LISTENERS_INPUTACTIONREPLAYLISTENER_H
